#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_INFINITES_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_INFINITES_HPP_INCLUDED

#include <boost/simd/constant/include/constants/infinites.hpp>

#endif
